Get all packages on search list
get_search_list_pkgs.RdThis function is meant to be used in combination with check_df_in_pkg()
Value
All items from search() with a package: prefix
get_search_list_pkgs.RdThis function is meant to be used in combination with check_df_in_pkg()
All items from search() with a package: prefix