Skip to contents

Dataset server module

Usage

mod_ds_server(id, pkg_input)

Arguments

id

module id

pkg_input

selected package

Value

shiny server module

Returned object (pkg_input)

The returned value passed to pkg_input is the result of the get_pkgs_with_dfs(), which returns a character vector of all packages with a data.frame or tibble in their exports.

mod_pkg_server is the precursor to mod_ds_server, and is intended to be return a character vector of packages (see example below):

pkg <- mod_pkg_server("pkg")

mod_ds_server("ds", pkg_input = pkg)