Check if package contains data.frame
check_df_in_pkg.RdReturns TRUE if package has data.frame. If package is not installed,
install with install.packages(dependencies = TRUE).
Check if the package is installed and load it
Retrieve the objects in the package
Use
purrr::map_lgl()to applyis.data.frame()to each object in the package.map_lgl()returns a logical vector with the same length as the retrieved package objects.